Resources and Handlers
======================

.. module:: rhino

.. autoclass:: Resource
   :members:

.. autofunction:: get
.. autofunction:: post
.. autofunction:: put
.. autofunction:: delete
.. autofunction:: patch
.. autofunction:: options

